/************************************************************************************
*                                                                                   *
*   File Name   : external_interrupts.c                                             *
*   Contents    : functions related with the EXTINT's 0,1 for Match Display         *
*   Version     : 1.6                                                               *
*************************************************************************************/ 
#include "sfr_r813.h"                       /* Definition of the R8C/10 SFR */
#include "output_handler.h"
#include "globals.h"

/************************************************************************************
Name:        EXTINT0_init
Parameters:  None
Returns:     None
Description: Initial setting of EXTINT0 registers
************************************************************************************/
void f_vd_EXTINTS_init(void)
{
	/* settings for INT0 */
	int0ic        = 0x00; /* interrupt disabled due to prio level 0 */
	pd4_5         = 0;    /* P4.5 = INT0 is input */
	pu11          = 1;    /* P4.5 pulled-up */
	int0en        = 1;    /* interrupt INT0 enabled */
	int0pl 	      = 1;    /* every edge counted */
	int0f         = 0;    /* no filter */
	pol_int0ic    = 0;    /* selects falling edge */
	ir_int0ic     = 0;    /* clear interrupt request flag */
	ilvl0_int0ic  = 1;
	ilvl1_int0ic  = 1;
	ilvl2_int0ic  = 1;    /* interrupt prio level7 */

	/* settings for INT1 */
	int1ic        = 0x00; /* interrupt disabled due to prio level 0 */
	pd1_7         = 0;    /* P1.7 = INT1 is input */
	pu03          = 1;    /* P1.4..P1.7 is pulled-up */
	r0edg         = 1;    /* selects falling edge */
	ir_int1ic     = 0;    /* clear interrupt request flag */
	ilvl0_int1ic  = 1;
	ilvl1_int1ic  = 1;
	ilvl2_int1ic  = 1;    /* interrupt prio level7 */
}

/************************************************************************************
Name:        interrupt Extint 0
Parameters:  None
Returns:     None
Description: ISR for EXTINT0 (Player1)
************************************************************************************/
#pragma interrupt Extint_0_int
void Extint_0_int(void)
{
unsigned int diff;
    diff = timerDifference (UI_int0_IRQ_timestamp, UI_TIRQ_count1ms);
	if (diff > cSwitchDebounceTimeMs) /* switch debouncing */
	{
		UI_int0_IRQ_timestamp = UI_TIRQ_count1ms; /* update timestamp of sucessfull IRQ */
        B_SWITCH_PLAYER1 = D_TRUE; /* set switch info flag */
	} //if (diff > cSwitchDebounceTimeMs)
}

/************************************************************************************
Name:        interrupt Extint 1
Parameters:  None
Returns:     None
Description: ISR for EXTINT1 (Player2)
************************************************************************************/
#pragma interrupt Extint_1_int
void Extint_1_int(void)
{
unsigned int diff;
	if (p1_7)
	{
   		r0edg         = 1;    /* selects falling edge */
	}
	else
	{
   		r0edg         = 0;    /* selects rising edge */
	}
	ir_int1ic     = 0;    /* clear interrupt request flag */
	diff = timerDifference (UI_int1_IRQ_timestamp, UI_TIRQ_count1ms);
	if (diff > cSwitchDebounceTimeMs) /* switch debouncing */
	{
		UI_int1_IRQ_timestamp = UI_TIRQ_count1ms; /* update timestamp of sucessfull IRQ */
        B_SWITCH_PLAYER2 = D_TRUE;
		/* change switching edge dependent on last one */
	} //if (diff > cSwitchDebounceTimeMs)
}

/***********************************************************************************/
